@@ -1,7 +1,4 @@
-//
-// Created by Kez Cleal on 25/07/2022.
-//
-#include <cassert>
+
 #include <algorithm>
 #include <filesystem>
 #include <htslib/faidx.h>
@@ -30,8 +27,8 @@
     #include <emscripten.h>
 #endif
 
-// note to developer - update version in workflows/main.yml, menu.cpp, term_out.cpp, and deps/gw.desktop, and installers .md in docs (post release)
-const char GW_VERSION [7] = "1.1.2";
+// note to developer - update version in Makefile, workflows/main.yml, menu.cpp, term_out.cpp, and deps/gw.desktop, and installers .md in docs (post release)
+const char GW_VERSION [7] = "1.1.4";
 // skia context has to be managed from global space to work
 GrDirectContext *sContext = nullptr;
 SkSurface *sSurface = nullptr;
