@@ -38,9 +38,18 @@
 #include "export_definitions.h"
 
 #define SK_GL
-#include "include/gpu/GrBackendSurface.h"
-#include "include/gpu/GrDirectContext.h"
-#include "include/gpu/gl/GrGLInterface.h"
+#ifndef OLD_SKIA
+    #include "include/gpu/ganesh/GrBackendSurface.h"
+    #include "include/gpu/ganesh/gl/GrGLDirectContext.h"
+    #include "include/gpu/ganesh/gl/GrGLInterface.h"
+    #include "include/gpu/ganesh/gl/GrGLBackendSurface.h"
+    #include "include/gpu/ganesh/SkSurfaceGanesh.h"
+#else
+    #include "include/gpu/GrBackendSurface.h"
+    #include "include/gpu/GrDirectContext.h"
+    #include "include/gpu/gl/GrGLInterface.h"
+#endif
+#include "include/encode/SkPngEncoder.h"
 #include "include/core/SkCanvas.h"
 #include "include/core/SkColorSpace.h"
 #include "include/core/SkSurface.h"
@@ -146,7 +155,6 @@ namespace Manager {
 
         faidx_t* fai;
         GLFWwindow* window;
-        GLFWwindow* backWindow;
 
         sk_sp<SkSurface> rasterSurface;
         sk_sp<SkSurface>* rasterSurfacePtr;  // option to use externally managed surface (faster)
